==> haskell-tasty-inspection-testing-0.2.1-313.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-inspection-testing.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-inspection-testing
version:              0.2.1
visibility:           public
id:                   tasty-inspection-testing-0.2.1-EeNqVea6uVn7mYwPhsxjwF
key:                  tasty-inspection-testing-0.2.1-EeNqVea6uVn7mYwPhsxjwF
license:              MIT
copyright:            2017 Joachim Breitner, 2021 Andrew Lelechenko
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Joachim Breitner, Andrew Lelechenko
homepage:             https://github.com/Bodigrim/tasty-inspection-testing
synopsis:             Inspection testing support for tasty
description:          Integrate @inspection-testing@ into @tasty@ test suites.
category:             Testing
abi:                  2c358be219d06da16df9f1344f09f648
exposed:              True
exposed-modules:      Test.Tasty.Inspection Test.Tasty.Inspection.Plugin
hidden-modules:       Test.Tasty.Inspection.Internal
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/tasty-inspection-testing-0.2.1

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/tasty-inspection-testing-0.2.1

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/tasty-inspection-testing-0.2.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-inspection-testing
hs-libraries:         HStasty-inspection-testing-0.2.1-EeNqVea6uVn7mYwPhsxjwF
depends:
    base-4.18.2.1 ghc-9.6.6
    inspection-testing-0.6.2-47cxnEk6Ffx5w0meYrAP5F
    tasty-1.5.2-K3PchMZYxV2JdxeMIpuhjP template-haskell-2.20.0.0

haddock-interfaces:
    /usr/share/doc/haskell-tasty-inspection-testing/html/tasty-inspection-testing.haddock

haddock-html:         /usr/share/doc/haskell-tasty-inspection-testing/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-inspection-testing-0.2.1-318-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-inspection-testing.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-inspection-testing
version:              0.2.1
visibility:           public
id:                   tasty-inspection-testing-0.2.1-1dUOhS6XLpr1ET5CR8XLM
key:                  tasty-inspection-testing-0.2.1-1dUOhS6XLpr1ET5CR8XLM
license:              MIT
copyright:            2017 Joachim Breitner, 2021 Andrew Lelechenko
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Joachim Breitner, Andrew Lelechenko
homepage:             https://github.com/Bodigrim/tasty-inspection-testing
synopsis:             Inspection testing support for tasty
description:          Integrate @inspection-testing@ into @tasty@ test suites.
category:             Testing
abi:                  0cbf5d9c9bb8a0a05e7e69143f0edacf
exposed:              True
exposed-modules:      Test.Tasty.Inspection Test.Tasty.Inspection.Plugin
hidden-modules:       Test.Tasty.Inspection.Internal
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/tasty-inspection-testing-0.2.1

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/tasty-inspection-testing-0.2.1

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/tasty-inspection-testing-0.2.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-inspection-testing
hs-libraries:         HStasty-inspection-testing-0.2.1-1dUOhS6XLpr1ET5CR8XLM
depends:
    base-4.18.2.1 ghc-9.6.6
    inspection-testing-0.6.2-47cxnEk6Ffx5w0meYrAP5F
    tasty-1.5.2-C3yI3pzTEHWEDVqwlNW4dB template-haskell-2.20.0.0

haddock-interfaces:
    /usr/share/doc/haskell-tasty-inspection-testing/html/tasty-inspection-testing.haddock

haddock-html:         /usr/share/doc/haskell-tasty-inspection-testing/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
